package MN::Subscr; # class to manage MyNews subscription

use strict;

@MN::Subscr::ISA = qw(MN::Object);

use MN::Object;

sub new # constructor
{
    my $class_name = shift;

    my $self = new MN::Object();
    
    bless $self, $class_name;

    return $self; # new Subscr object
}
sub getClass # get database table for the class 
{
    return "mnsubscr"; # "mnsubscr"
}

sub getKey # get database key for the class
{
    return "template,user"; # "template,user"
}

sub getFields # get database fields for the class
{
    return { # fields hash table
	"template" => "string",
	"user" => "string",
    };
}

1;

__END__

=pod

=head1 NAME

MN::Subscr - MyNews class to manage user subscriptions.

=head1 SYNOPSIS

 use strict;
 use MN 1.0;

 my $mne = new MN::Engine();
 my $cgi = new MN::CGI();
 my $user = $cgi->getUser();
 my @sbs = MN::Subscr->getObjects("user = '$user->{login}'");
 ...

=head1 DESCRIPTION

MyNews Subscr objects store links between users and templates.

MN::Subscr inherits from MN::Object, that means that user subscriptions are stored in database.

=over 4

=head2 Fields

=item template : string

Template id the user has subscribed to.

=item user : string

User login of the subscriber.

=head1 SEE ALSO

L<MN::Object>, L<MN::User>, L<MN::Template>

=cut
